/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2007 University of Washington
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Craig Dowell <craigdo@ee.washington.edu>
 */

#ifndef FW_ASCII_TRACE_H
#define FW_ASCII_TRACE_H

#include <fstream>
#include "ns3/packet.h"
#include "ns3/trace-context.h"

namespace ns3 {

/**
 * \brief Simple Ascii Tracing Framework.
 *
 * This class specializes a framework for implementing a simple tracing
 * system as would be used by a casual user of the Ns-3 system.
 */
class AsciiTraceFramework
{
public:
  AsciiTraceFramework ();
  virtual ~AsciiTraceFramework ();

  virtual void Open (std::string filename);

  virtual void TraceQueues (void);
  virtual void TraceNetDeviceRx (void);

protected:
  virtual void LogQueue (TraceContext const &context, Packet const &p);
  virtual void LogNetDeviceRx (TraceContext const &context, Packet &p);

  std::ofstream m_os;

private:
};

} // namespace ns3

#endif /* FW_ASCII_TRACE_H */
