/* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
/*
 * Copyright (c) 2007 University of Washington
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include "ns3/debug.h"
#include "fw-base.h"

NS_DEBUG_COMPONENT_DEFINE ("SimulationFrameworkBase");

using namespace ns3;

SimulationFrameworkBase::SimulationFrameworkBase ()
{
  NS_DEBUG("SimulationFrameworkBase::SimulationFrameworkBase ()");
  InitBase ();
}

SimulationFrameworkBase::~SimulationFrameworkBase ()
{
  NS_DEBUG("SimulationFrameworkBase::~SimulationFrameworkBase ()");
  CleanupBase ();
}

  void
SimulationFrameworkBase::Run (void)
{
  NS_DEBUG("SimulationFrameworkBase::Run ()");

  InitStaticEnv ();
  InitDynamicEnv  ();
  InitTopology ();

  PreSimulation  ();
  Simulate ();
  PostSimulation ();

  CleanupTopology  ();
  CleanupDynamicEnv ();
  CleanupStaticEnv ();
}

  void
SimulationFrameworkBase::InitBase (void)
{
  NS_DEBUG("SimulationFrameworkBase::InitBase ()");
}

  void
SimulationFrameworkBase::InitStaticEnv (void)
{
  NS_DEBUG("SimulationFrameworkBase::InitStaticEnv ()");
}

  void
SimulationFrameworkBase::InitDynamicEnv (void)
{
  NS_DEBUG("SimulationFrameworkBase::InitDynamicEnv ()");
}

  void
SimulationFrameworkBase::InitTopology (void)
{
  NS_DEBUG("SimulationFrameworkBase::InitTopology ()");
}

  void
SimulationFrameworkBase::PreSimulation (void)
{
  NS_DEBUG("SimulationFrameworkBase::PreSimulation ()");
}

  void
SimulationFrameworkBase::Simulate (void)
{
  NS_DEBUG("SimulationFrameworkBase::Simulate ()");
}

  void
SimulationFrameworkBase::PostSimulation (void)
{
  NS_DEBUG("SimulationFrameworkBase::PostSimulation ()");
}

  void
SimulationFrameworkBase::CleanupTopology (void)
{
  NS_DEBUG("SimulationFrameworkBase::CleanupTopology ()");
}

  void
SimulationFrameworkBase::CleanupDynamicEnv (void)
{
  NS_DEBUG("SimulationFrameworkBase::CleanupDynamicEnv ()");
}

  void
SimulationFrameworkBase::CleanupStaticEnv (void)
{
  NS_DEBUG("SimulationFrameworkBase::CleanupStaticEnv ()");
}

  void
SimulationFrameworkBase::CleanupBase (void)
{
  NS_DEBUG("SimulationFrameworkBase::CleanupBase ()");
  Simulator::Destroy ();
}

  void
SimulationFrameworkBase::CreateIPAddress(void)
{
  NS_DEBUG("SimulationFrameworkBase::CreateIPAddress ()");
}

  void
SimulationFrameworkBase::CreateMACAddress(void)
{
  NS_DEBUG("SimulationFrameworkBase::CreateMACAddress ()");
}
